#include <Rcpp.h>
using namespace Rcpp;

// [[Rcpp::export]]
NumericMatrix gibbs_cpp(int N, int thin) {
    
    NumericMatrix mat(N, 2);
    double x = 0, y = 0;
    
    for(int i = 0; i < N; i++) {
        for(int j = 0; j < thin; j++) {
            x = rgamma(1, 3, 1 / (y * y + 4))[0];
            y = rnorm(1, 1 / (x + 1), 1 / sqrt(2 * (x + 1)))[0];
        }
        mat(i, 0) = x;
        mat(i, 1) = y;
    }
    
    return(mat);
}

double vacc3a(double age, bool female, bool ily){
    double p = 0.25 + 0.3 * 1 / (1 - exp(0.04 * age)) + 0.1 * ily;
    p = p * (female ? 1.25 : 0.75);
    p = std::max(p, 0.0);
    p = std::min(p, 1.0);
    return p;
}

// [[Rcpp::export]]
NumericVector vacc3(NumericVector age, LogicalVector female, LogicalVector ily) {
    
    int n = age.size();
    NumericVector out(n);
    
    for(int i = 0; i < n; ++i) {
        out[i] = vacc3a(age[i], female[i], ily[i]);
    }
    
    return out;
}